@@ -23,16 +23,19 @@
 
 #include <stdio.h>
 
+// Enable this to get full debugging output
 //#define _DEBUG
 
 #ifdef _DEBUG
 #undef NODEBUG
 #endif
 
-#define LOGDEBUG        0
+#define LOGCRIT         0
 #define LOGERROR        1
 #define LOGWARNING	2
 #define LOGINFO		3
+#define LOGDEBUG	4
+#define LOGALL		5
 
 void LogSetOutput(FILE *file);
 void LogPrintf(const char *format, ...);
@@ -41,4 +44,3 @@ void LogHex(const char *data, unsigned long len);
 void LogHexString(const char *data, unsigned long len);
 
 #endif
-
